pub struct CopyArtifactParams {
pub project_name: String,
pub repository_name: String,
pub from: String,
pub x_request_id: Option<String>,
}Expand description
struct for passing parameters to the method copy_artifact
Fields
project_name: StringThe name of the project
repository_name: StringThe name of the repository. If it contains slash, encode it twice over with URL encoding. e.g. a/b -> a%2Fb -> a%252Fb
from: StringThe artifact from which the new artifact is copied from, the format should be "project/repository:tag" or "project/repository@digest".
x_request_id: Option<String>An unique ID for the request