pub struct GetAdditionParams {
pub project_name: String,
pub repository_name: String,
pub reference: String,
pub addition: String,
pub x_request_id: Option<String>,
}Expand description
struct for passing parameters to the method get_addition
Fields
project_name: StringThe name of the project
repository_name: StringThe name of the repository. If it contains slash, encode it twice over with URL encoding. e.g. a/b -> a%2Fb -> a%252Fb
reference: StringThe reference of the artifact, can be digest or tag
addition: StringThe type of addition.
x_request_id: Option<String>An unique ID for the request