pub struct RemoveLabelParams {
pub project_name: String,
pub repository_name: String,
pub reference: String,
pub label_id: i64,
pub x_request_id: Option<String>,
}Expand description
struct for passing parameters to the method remove_label
Fields
project_name: StringThe name of the project
repository_name: StringThe name of the repository. If it contains slash, encode it twice over with URL encoding. e.g. a/b -> a%2Fb -> a%252Fb
reference: StringThe reference of the artifact, can be digest or tag
label_id: i64The ID of the label that removed from the artifact.
x_request_id: Option<String>An unique ID for the request