pub struct UpdateConfigurationsParams {
pub configurations: Configurations,
pub x_request_id: Option<String>,
}Expand description
struct for passing parameters to the method update_configurations
Fields
configurations: ConfigurationsThe configuration map can contain a subset of the attributes of the schema, which are to be updated.
x_request_id: Option<String>An unique ID for the request