Module immutable_api

Module immutable_api 

Structs

CreateImmuRuleParams
struct for passing parameters to the method create_immu_rule
DeleteImmuRuleParams
struct for passing parameters to the method delete_immu_rule
ListImmuRulesParams
struct for passing parameters to the method list_immu_rules
UpdateImmuRuleParams
struct for passing parameters to the method update_immu_rule

Enums

CreateImmuRuleError
struct for typed errors of method create_immu_rule
DeleteImmuRuleError
struct for typed errors of method delete_immu_rule
ListImmuRulesError
struct for typed errors of method list_immu_rules
UpdateImmuRuleError
struct for typed errors of method update_immu_rule

Functions

create_immu_rule
This endpoint add an immutable tag rule to the project
delete_immu_rule
list_immu_rules
This endpoint returns the immutable tag rules of a project
update_immu_rule