Structs
- Create
Label Params - struct for passing parameters to the method
create_label - Delete
Label Params - struct for passing parameters to the method
delete_label - GetLabel
ById Params - struct for passing parameters to the method
get_label_by_id - List
Labels Params - struct for passing parameters to the method
list_labels - Update
Label Params - struct for passing parameters to the method
update_label
Enums
- Create
Label Error - struct for typed errors of method
create_label - Delete
Label Error - struct for typed errors of method
delete_label - GetLabel
ById Error - struct for typed errors of method
get_label_by_id - List
Labels Error - struct for typed errors of method
list_labels - Update
Label Error - struct for typed errors of method
update_label
Functions
- create_
label - This endpoint let user creates a label.
- delete_
label - Delete the label specified by ID.
- get_
label_ by_ id - This endpoint let user get the label by specific ID.
- list_
labels - This endpoint let user list labels by name, scope and project_id
- update_
label - This endpoint let user update label properties.