Module ping_api

Module ping_api 

Structs

GetPingParams
struct for passing parameters to the method get_ping

Enums

GetPingError
struct for typed errors of method get_ping

Functions

get_ping
This API simply replies a pong to indicate the process to handle API is up, disregarding the health status of dependent components. This path does not require any authentication.