Module project_api

Module project_api 

Structs

CreateProjectParams
struct for passing parameters to the method create_project
DeleteProjectParams
struct for passing parameters to the method delete_project
GetLogsParams
struct for passing parameters to the method get_logs
GetProjectDeletableParams
struct for passing parameters to the method get_project_deletable
GetProjectParams
struct for passing parameters to the method get_project
GetProjectSummaryParams
struct for passing parameters to the method get_project_summary
GetScannerOfProjectParams
struct for passing parameters to the method get_scanner_of_project
HeadProjectParams
struct for passing parameters to the method head_project
ListArtifactsOfProjectParams
struct for passing parameters to the method list_artifacts_of_project
ListProjectsParams
struct for passing parameters to the method list_projects
ListScannerCandidatesOfProjectParams
struct for passing parameters to the method list_scanner_candidates_of_project
SetScannerOfProjectParams
struct for passing parameters to the method set_scanner_of_project
UpdateProjectParams
struct for passing parameters to the method update_project

Enums

CreateProjectError
struct for typed errors of method create_project
DeleteProjectError
struct for typed errors of method delete_project
GetLogsError
struct for typed errors of method get_logs
GetProjectDeletableError
struct for typed errors of method get_project_deletable
GetProjectError
struct for typed errors of method get_project
GetProjectSummaryError
struct for typed errors of method get_project_summary
GetScannerOfProjectError
struct for typed errors of method get_scanner_of_project
HeadProjectError
struct for typed errors of method head_project
ListArtifactsOfProjectError
struct for typed errors of method list_artifacts_of_project
ListProjectsError
struct for typed errors of method list_projects
ListScannerCandidatesOfProjectError
struct for typed errors of method list_scanner_candidates_of_project
SetScannerOfProjectError
struct for typed errors of method set_scanner_of_project
UpdateProjectError
struct for typed errors of method update_project

Functions

create_project
This endpoint is for user to create a new project.
delete_project
This endpoint is aimed to delete project by project ID.
get_logs
Get recent logs of the projects
get_project
This endpoint returns specific project information by project ID.
get_project_deletable
Get the deletable status of the project
get_project_summary
Get summary of the project.
get_scanner_of_project
Get the scanner registration of the specified project. If no scanner registration is configured for the specified project, the system default scanner registration will be returned.
head_project
This endpoint is used to check if the project name provided already exist.
list_artifacts_of_project
List artifacts of the specified project
list_projects
This endpoint returns projects created by Harbor.
list_scanner_candidates_of_project
Retrieve the system configured scanner registrations as candidates of setting project level scanner.
set_scanner_of_project
Set one of the system configured scanner registration as the indepndent scanner of the specified project.
update_project
This endpoint is aimed to update the properties of a project.