pub async fn create_project(
configuration: &Configuration,
params: CreateProjectParams,
) -> Result<(), Error<CreateProjectError>>Expand description
This endpoint is for user to create a new project.
pub async fn create_project(
configuration: &Configuration,
params: CreateProjectParams,
) -> Result<(), Error<CreateProjectError>>This endpoint is for user to create a new project.