pub struct CreateProjectParams {
pub project: ProjectReq,
pub x_request_id: Option<String>,
pub x_resource_name_in_location: Option<bool>,
}Expand description
struct for passing parameters to the method create_project
Fields
project: ProjectReqNew created project.
x_request_id: Option<String>An unique ID for the request
x_resource_name_in_location: Option<bool>The flag to indicate whether to return the name of the resource in Location. When X-Resource-Name-In-Location is true, the Location will return the name of the resource.