pub struct ListProjectsParams {
pub x_request_id: Option<String>,
pub q: Option<String>,
pub page: Option<i64>,
pub page_size: Option<i64>,
pub sort: Option<String>,
pub name: Option<String>,
pub public: Option<bool>,
pub owner: Option<String>,
pub with_detail: Option<bool>,
}Expand description
struct for passing parameters to the method list_projects
Fields
x_request_id: Option<String>An unique ID for the request
q: Option<String>Query string to query resources. Supported query patterns are "exact match(k=v)", "fuzzy match(k=~v)", "range(k=[min~max])", "list with union releationship(k={v1 v2 v3})" and "list with intersetion relationship(k=(v1 v2 v3))". The value of range and list can be string(enclosed by " or ’), integer or time(in format "2020-04-09 02:36:00"). All of these query patterns should be put in the query string "q=xxx" and splitted by ",". e.g. q=k1=v1,k2=~v2,k3=[min~max]
page: Option<i64>The page number
page_size: Option<i64>The size of per page
sort: Option<String>Sort the resource list in ascending or descending order. e.g. sort by field1 in ascending order and field2 in descending order with "sort=field1,-field2"
name: Option<String>The name of project.
public: Option<bool>The project is public or private.
owner: Option<String>The name of project owner.
with_detail: Option<bool>Bool value indicating whether return detailed information of the project