pub struct AddProjectMetadatasParams {
pub project_name_or_id: String,
pub x_request_id: Option<String>,
pub x_is_resource_name: Option<bool>,
pub metadata: Option<HashMap<String, String>>,
}Expand description
struct for passing parameters to the method add_project_metadatas
Fields
project_name_or_id: StringThe name or id of the project
x_request_id: Option<String>An unique ID for the request
x_is_resource_name: Option<bool>The flag to indicate whether the parameter which supports both name and id in the path is the name of the resource. When the X-Is-Resource-Name is false and the parameter can be converted to an integer, the parameter will be as an id, otherwise, it will be as a name.
metadata: Option<HashMap<String, String>>Trait Implementations
Sourceimpl Clone for AddProjectMetadatasParams
impl Clone for AddProjectMetadatasParams
Sourcefn clone(&self) -> AddProjectMetadatasParams
fn clone(&self) -> AddProjectMetadatasParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for AddProjectMetadatasParams
impl RefUnwindSafe for AddProjectMetadatasParams
impl Send for AddProjectMetadatasParams
impl Sync for AddProjectMetadatasParams
impl Unpin for AddProjectMetadatasParams
impl UnsafeUnpin for AddProjectMetadatasParams
impl UnwindSafe for AddProjectMetadatasParams