Module purge_api

Module purge_api 

Structs

CreatePurgeScheduleParams
struct for passing parameters to the method create_purge_schedule
GetPurgeHistoryParams
struct for passing parameters to the method get_purge_history
GetPurgeJobLogParams
struct for passing parameters to the method get_purge_job_log
GetPurgeJobParams
struct for passing parameters to the method get_purge_job
GetPurgeScheduleParams
struct for passing parameters to the method get_purge_schedule
StopPurgeParams
struct for passing parameters to the method stop_purge
UpdatePurgeScheduleParams
struct for passing parameters to the method update_purge_schedule

Enums

CreatePurgeScheduleError
struct for typed errors of method create_purge_schedule
GetPurgeHistoryError
struct for typed errors of method get_purge_history
GetPurgeJobError
struct for typed errors of method get_purge_job
GetPurgeJobLogError
struct for typed errors of method get_purge_job_log
GetPurgeScheduleError
struct for typed errors of method get_purge_schedule
StopPurgeError
struct for typed errors of method stop_purge
UpdatePurgeScheduleError
struct for typed errors of method update_purge_schedule

Functions

create_purge_schedule
This endpoint is for update purge job schedule.
get_purge_history
get purge job execution history.
get_purge_job
This endpoint let user get purge job status filtered by specific ID.
get_purge_job_log
This endpoint let user get purge job logs filtered by specific ID.
get_purge_schedule
This endpoint is for get schedule of purge job.
stop_purge
Stop the purge audit log execution specified by ID
update_purge_schedule
This endpoint is for update purge job schedule.