pub struct ListReplicationExecutionsParams {
pub x_request_id: Option<String>,
pub sort: Option<String>,
pub page: Option<i64>,
pub page_size: Option<i64>,
pub policy_id: Option<i32>,
pub status: Option<String>,
pub trigger: Option<String>,
}Expand description
struct for passing parameters to the method list_replication_executions
Fields
x_request_id: Option<String>An unique ID for the request
sort: Option<String>Sort the resource list in ascending or descending order. e.g. sort by field1 in ascending order and field2 in descending order with "sort=field1,-field2"
page: Option<i64>The page number
page_size: Option<i64>The size of per page
policy_id: Option<i32>The ID of the policy that the executions belong to.
status: Option<String>The execution status.
trigger: Option<String>The trigger mode.