pub struct ListReplicationTasksParams {
pub id: i64,
pub x_request_id: Option<String>,
pub sort: Option<String>,
pub page: Option<i64>,
pub page_size: Option<i64>,
pub status: Option<String>,
pub resource_type: Option<String>,
}Expand description
struct for passing parameters to the method list_replication_tasks
Fields
id: i64The ID of the execution that the tasks belongs to.
x_request_id: Option<String>An unique ID for the request
sort: Option<String>Sort the resource list in ascending or descending order. e.g. sort by field1 in ascending order and field2 in descending order with "sort=field1,-field2"
page: Option<i64>The page number
page_size: Option<i64>The size of per page
status: Option<String>The task status.
resource_type: Option<String>The resource type.