Module robot_api

Module robot_api 

Structs

CreateRobotParams
struct for passing parameters to the method create_robot
DeleteRobotParams
struct for passing parameters to the method delete_robot
GetRobotByIdParams
struct for passing parameters to the method get_robot_by_id
ListRobotParams
struct for passing parameters to the method list_robot
RefreshSecParams
struct for passing parameters to the method refresh_sec
UpdateRobotParams
struct for passing parameters to the method update_robot

Enums

CreateRobotError
struct for typed errors of method create_robot
DeleteRobotError
struct for typed errors of method delete_robot
GetRobotByIdError
struct for typed errors of method get_robot_by_id
ListRobotError
struct for typed errors of method list_robot
RefreshSecError
struct for typed errors of method refresh_sec
UpdateRobotError
struct for typed errors of method update_robot

Functions

create_robot
Create a robot account
delete_robot
This endpoint deletes specific robot account information by robot ID.
get_robot_by_id
This endpoint returns specific robot account information by robot ID.
list_robot
List the robot accounts with the specified level and project.
refresh_sec
Refresh the robot secret
update_robot
This endpoint updates specific robot account information by robot ID.