pub struct ScanArtifactParams {
pub project_name: String,
pub repository_name: String,
pub reference: String,
pub x_request_id: Option<String>,
pub scan_type: Option<HarborScanType>,
}Expand description
struct for passing parameters to the method scan_artifact
Fields
project_name: StringThe name of the project
repository_name: StringThe name of the repository. If it contains slash, encode it twice over with URL encoding. e.g. a/b -> a%2Fb -> a%252Fb
reference: StringThe reference of the artifact, can be digest or tag
x_request_id: Option<String>An unique ID for the request
scan_type: Option<HarborScanType>Trait Implementations
Sourceimpl Clone for ScanArtifactParams
impl Clone for ScanArtifactParams
Sourcefn clone(&self) -> ScanArtifactParams
fn clone(&self) -> ScanArtifactParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ScanArtifactParams
impl RefUnwindSafe for ScanArtifactParams
impl Send for ScanArtifactParams
impl Sync for ScanArtifactParams
impl Unpin for ScanArtifactParams
impl UnwindSafe for ScanArtifactParams