pub struct StopScanArtifactParams {
pub project_name: String,
pub repository_name: String,
pub reference: String,
pub scan_type: HarborScanType,
pub x_request_id: Option<String>,
}Expand description
struct for passing parameters to the method stop_scan_artifact
Fields
project_name: StringThe name of the project
repository_name: StringThe name of the repository. If it contains slash, encode it twice over with URL encoding. e.g. a/b -> a%2Fb -> a%252Fb
reference: StringThe reference of the artifact, can be digest or tag
scan_type: HarborScanTypeThe scan type: Vulnerabilities, SBOM
x_request_id: Option<String>An unique ID for the request