Module scan_data_export_api

Module scan_data_export_api 

Structs

DownloadScanDataParams
struct for passing parameters to the method download_scan_data
ExportScanDataParams
struct for passing parameters to the method export_scan_data
GetScanDataExportExecutionListParams
struct for passing parameters to the method get_scan_data_export_execution_list
GetScanDataExportExecutionParams
struct for passing parameters to the method get_scan_data_export_execution

Enums

DownloadScanDataError
struct for typed errors of method download_scan_data
ExportScanDataError
struct for typed errors of method export_scan_data
GetScanDataExportExecutionError
struct for typed errors of method get_scan_data_export_execution
GetScanDataExportExecutionListError
struct for typed errors of method get_scan_data_export_execution_list

Functions

download_scan_data
Download the scan data report. Default format is CSV
export_scan_data
Export scan data for selected projects
get_scan_data_export_execution
Get the scan data export execution specified by ID
get_scan_data_export_execution_list
Get a list of specific scan data export execution jobs for a specified user