Module scanner_api

Module scanner_api 

Structs

CreateScannerParams
struct for passing parameters to the method create_scanner
DeleteScannerParams
struct for passing parameters to the method delete_scanner
GetScannerMetadataParams
struct for passing parameters to the method get_scanner_metadata
GetScannerParams
struct for passing parameters to the method get_scanner
ListScannersParams
struct for passing parameters to the method list_scanners
PingScannerParams
struct for passing parameters to the method ping_scanner
SetScannerAsDefaultParams
struct for passing parameters to the method set_scanner_as_default
UpdateScannerParams
struct for passing parameters to the method update_scanner

Enums

CreateScannerError
struct for typed errors of method create_scanner
DeleteScannerError
struct for typed errors of method delete_scanner
GetScannerError
struct for typed errors of method get_scanner
GetScannerMetadataError
struct for typed errors of method get_scanner_metadata
ListScannersError
struct for typed errors of method list_scanners
PingScannerError
struct for typed errors of method ping_scanner
SetScannerAsDefaultError
struct for typed errors of method set_scanner_as_default
UpdateScannerError
struct for typed errors of method update_scanner

Functions

create_scanner
Creats a new scanner registration with the given data.
delete_scanner
Deletes the specified scanner registration.
get_scanner
Retruns the details of the specified scanner registration.
get_scanner_metadata
Get the metadata of the specified scanner registration, including the capabilities and customized properties.
list_scanners
Returns a list of currently configured scanner registrations.
ping_scanner
Pings scanner adapter to test endpoint URL and authorization settings.
set_scanner_as_default
Set the specified scanner registration as the system default one.
update_scanner
Updates the specified scanner registration.