pub async fn create_scanner(
configuration: &Configuration,
params: CreateScannerParams,
) -> Result<(), Error<CreateScannerError>>Expand description
Creats a new scanner registration with the given data.
pub async fn create_scanner(
configuration: &Configuration,
params: CreateScannerParams,
) -> Result<(), Error<CreateScannerError>>Creats a new scanner registration with the given data.