Module search_api

Module search_api 

Structs

SearchParams
struct for passing parameters to the method search

Enums

SearchError
struct for typed errors of method search

Functions

search
The Search endpoint returns information about the projects and repositories offered at public status or related to the current logged in user. The response includes the project and repository list in a proper display order.