pub struct ListVulnerabilitiesParams {
pub x_request_id: Option<String>,
pub q: Option<String>,
pub page: Option<i64>,
pub page_size: Option<i64>,
pub tune_count: Option<bool>,
pub with_tag: Option<bool>,
}Expand description
struct for passing parameters to the method list_vulnerabilities
Fields
x_request_id: Option<String>An unique ID for the request
q: Option<String>Query string to query resources. Supported query patterns are "exact match(k=v)", "fuzzy match(k=~v)", "range(k=[min~max])", "list with union releationship(k={v1 v2 v3})" and "list with intersetion relationship(k=(v1 v2 v3))". The value of range and list can be string(enclosed by " or ’), integer or time(in format "2020-04-09 02:36:00"). All of these query patterns should be put in the query string "q=xxx" and splitted by ",". e.g. q=k1=v1,k2=~v2,k3=[min~max]
page: Option<i64>The page number
page_size: Option<i64>The size of per page
tune_count: Option<bool>Enable to ignore X-Total-Count when the total count > 1000, if the total count is less than 1000, the real total count is returned, else -1.
with_tag: Option<bool>Specify whether the tag information is included inside vulnerability information