Module systeminfo_api

Module systeminfo_api 

Structs

GetCertParams
struct for passing parameters to the method get_cert
GetSystemInfoParams
struct for passing parameters to the method get_system_info
GetVolumesParams
struct for passing parameters to the method get_volumes

Enums

GetCertError
struct for typed errors of method get_cert
GetSystemInfoError
struct for typed errors of method get_system_info
GetVolumesError
struct for typed errors of method get_volumes

Functions

get_cert
This endpoint is for downloading a default root certificate.
get_system_info
This API is for retrieving general system info, this can be called by anonymous request. Some attributes will be omitted in the response when this API is called by anonymous request.
get_volumes
This endpoint is for retrieving system volume info that only provides for admin user. Note that the response only reflects the storage status of local disk.