Module user_api

Module user_api 

Structs

CreateUserParams
struct for passing parameters to the method create_user
DeleteUserParams
struct for passing parameters to the method delete_user
GetCurrentUserInfoParams
struct for passing parameters to the method get_current_user_info
GetCurrentUserPermissionsParams
struct for passing parameters to the method get_current_user_permissions
GetUserParams
struct for passing parameters to the method get_user
ListUsersParams
struct for passing parameters to the method list_users
SearchUsersParams
struct for passing parameters to the method search_users
SetCliSecretParams
struct for passing parameters to the method set_cli_secret
SetUserSysAdminParams
struct for passing parameters to the method set_user_sys_admin
UpdateUserPasswordParams
struct for passing parameters to the method update_user_password
UpdateUserProfileParams
struct for passing parameters to the method update_user_profile

Enums

CreateUserError
struct for typed errors of method create_user
DeleteUserError
struct for typed errors of method delete_user
GetCurrentUserInfoError
struct for typed errors of method get_current_user_info
GetCurrentUserPermissionsError
struct for typed errors of method get_current_user_permissions
GetUserError
struct for typed errors of method get_user
ListUsersError
struct for typed errors of method list_users
SearchUsersError
struct for typed errors of method search_users
SetCliSecretError
struct for typed errors of method set_cli_secret
SetUserSysAdminError
struct for typed errors of method set_user_sys_admin
UpdateUserPasswordError
struct for typed errors of method update_user_password
UpdateUserProfileError
struct for typed errors of method update_user_profile

Functions

create_user
This API can be used only when the authentication mode is for local DB. When self registration is disabled.
delete_user
This endpoint let administrator of Harbor mark a registered user as removed.It actually won’t be deleted from DB.
get_current_user_info
get_current_user_permissions
get_user
list_users
search_users
This endpoint is to search the users by username. It’s open for all authenticated requests.
set_cli_secret
This endpoint let user generate a new CLI secret for himself. This API only works when auth mode is set to ‘OIDC’. Once this API returns with successful status, the old secret will be invalid, as there will be only one CLI secret for a user.
set_user_sys_admin
update_user_password
This endpoint is for user to update password. Users with the admin role can change any user’s password. Regular users can change only their own password.
update_user_profile