Module webhook_api

Module webhook_api 

Structs

CreateWebhookPolicyOfProjectParams
struct for passing parameters to the method create_webhook_policy_of_project
DeleteWebhookPolicyOfProjectParams
struct for passing parameters to the method delete_webhook_policy_of_project
GetLogsOfWebhookTaskParams
struct for passing parameters to the method get_logs_of_webhook_task
GetSupportedEventTypesParams
struct for passing parameters to the method get_supported_event_types
GetWebhookPolicyOfProjectParams
struct for passing parameters to the method get_webhook_policy_of_project
LastTriggerParams
struct for passing parameters to the method last_trigger
ListExecutionsOfWebhookPolicyParams
struct for passing parameters to the method list_executions_of_webhook_policy
ListTasksOfWebhookExecutionParams
struct for passing parameters to the method list_tasks_of_webhook_execution
ListWebhookPoliciesOfProjectParams
struct for passing parameters to the method list_webhook_policies_of_project
UpdateWebhookPolicyOfProjectParams
struct for passing parameters to the method update_webhook_policy_of_project

Enums

CreateWebhookPolicyOfProjectError
struct for typed errors of method create_webhook_policy_of_project
DeleteWebhookPolicyOfProjectError
struct for typed errors of method delete_webhook_policy_of_project
GetLogsOfWebhookTaskError
struct for typed errors of method get_logs_of_webhook_task
GetSupportedEventTypesError
struct for typed errors of method get_supported_event_types
GetWebhookPolicyOfProjectError
struct for typed errors of method get_webhook_policy_of_project
LastTriggerError
struct for typed errors of method last_trigger
ListExecutionsOfWebhookPolicyError
struct for typed errors of method list_executions_of_webhook_policy
ListTasksOfWebhookExecutionError
struct for typed errors of method list_tasks_of_webhook_execution
ListWebhookPoliciesOfProjectError
struct for typed errors of method list_webhook_policies_of_project
UpdateWebhookPolicyOfProjectError
struct for typed errors of method update_webhook_policy_of_project

Functions

create_webhook_policy_of_project
This endpoint create a webhook policy if the project does not have one.
delete_webhook_policy_of_project
This endpoint is aimed to delete webhookpolicy of a project.
get_logs_of_webhook_task
This endpoint returns the logs of a specific webhook task.
get_supported_event_types
Get supported event types and notify types.
get_webhook_policy_of_project
This endpoint returns specified webhook policy of a project.
last_triggerDeprecated
This endpoint returns last trigger information of project webhook policy.
list_executions_of_webhook_policy
This endpoint returns the executions of a specific webhook policy.
list_tasks_of_webhook_execution
This endpoint returns the tasks of a specific webhook execution.
list_webhook_policies_of_project
This endpoint returns webhook policies of a project.
update_webhook_policy_of_project
This endpoint is aimed to update the webhook policy of a project.