pub struct GetWebhookPolicyOfProjectParams {
pub project_name_or_id: String,
pub webhook_policy_id: i64,
pub x_request_id: Option<String>,
pub x_is_resource_name: Option<bool>,
}Expand description
struct for passing parameters to the method get_webhook_policy_of_project
Fields
project_name_or_id: StringThe name or id of the project
webhook_policy_id: i64The ID of the webhook policy
x_request_id: Option<String>An unique ID for the request
x_is_resource_name: Option<bool>The flag to indicate whether the parameter which supports both name and id in the path is the name of the resource. When the X-Is-Resource-Name is false and the parameter can be converted to an integer, the parameter will be as an id, otherwise, it will be as a name.