pub struct ListWebhookPoliciesOfProjectParams {
pub project_name_or_id: String,
pub x_request_id: Option<String>,
pub x_is_resource_name: Option<bool>,
pub sort: Option<String>,
pub q: Option<String>,
pub page: Option<i64>,
pub page_size: Option<i64>,
}Expand description
struct for passing parameters to the method list_webhook_policies_of_project
Fields
project_name_or_id: StringThe name or id of the project
x_request_id: Option<String>An unique ID for the request
x_is_resource_name: Option<bool>The flag to indicate whether the parameter which supports both name and id in the path is the name of the resource. When the X-Is-Resource-Name is false and the parameter can be converted to an integer, the parameter will be as an id, otherwise, it will be as a name.
sort: Option<String>Sort the resource list in ascending or descending order. e.g. sort by field1 in ascending order and field2 in descending order with "sort=field1,-field2"
q: Option<String>Query string to query resources. Supported query patterns are "exact match(k=v)", "fuzzy match(k=~v)", "range(k=[min~max])", "list with union releationship(k={v1 v2 v3})" and "list with intersetion relationship(k=(v1 v2 v3))". The value of range and list can be string(enclosed by " or ’), integer or time(in format "2020-04-09 02:36:00"). All of these query patterns should be put in the query string "q=xxx" and splitted by ",". e.g. q=k1=v1,k2=~v2,k3=[min~max]
page: Option<i64>The page number
page_size: Option<i64>The size of per page