pub struct Access {
pub resource: Option<String>,
pub action: Option<String>,
pub effect: Option<String>,
}Fields
resource: Option<String>The resource of the access. Possible resources are listed here for system and project level https://github.com/goharbor/harbor/blob/main/src/common/rbac/const.go
action: Option<String>The action of the access. Possible actions are *, pull, push, create, read, update, delete, list, operate, scanner-pull and stop.
effect: Option<String>The effect of the access
Implementations