Artifact

Struct Artifact 

pub struct Artifact {
Show 22 fields pub id: Option<i64>, pub type: Option<String>, pub media_type: Option<String>, pub manifest_media_type: Option<String>, pub artifact_type: Option<String>, pub project_id: Option<i64>, pub repository_id: Option<i64>, pub repository_name: Option<String>, pub digest: Option<String>, pub size: Option<i64>, pub icon: Option<String>, pub push_time: Option<String>, pub pull_time: Option<String>, pub extra_attrs: Option<HashMap<String, Value>>, pub annotations: Option<HashMap<String, String>>, pub references: Option<Vec<Reference>>, pub tags: Option<Vec<Tag>>, pub addition_links: Option<HashMap<String, AdditionLink>>, pub labels: Option<Vec<Label>>, pub scan_overview: Option<HashMap<String, NativeReportSummary>>, pub sbom_overview: Option<Box<SbomOverview>>, pub accessories: Option<Vec<Accessory>>,
}

Fields

id: Option<i64>

The ID of the artifact

type: Option<String>

The type of the artifact, e.g. image, chart, etc

media_type: Option<String>

The media type of the artifact

manifest_media_type: Option<String>

The manifest media type of the artifact

artifact_type: Option<String>

The artifact_type in the manifest of the artifact

project_id: Option<i64>

The ID of the project that the artifact belongs to

repository_id: Option<i64>

The ID of the repository that the artifact belongs to

repository_name: Option<String>

The name of the repository that the artifact belongs to

digest: Option<String>

The digest of the artifact

size: Option<i64>

The size of the artifact

icon: Option<String>

The digest of the icon

push_time: Option<String>

The push time of the artifact

pull_time: Option<String>

The latest pull time of the artifact

extra_attrs: Option<HashMap<String, Value>>annotations: Option<HashMap<String, String>>references: Option<Vec<Reference>>tags: Option<Vec<Tag>>addition_links: Option<HashMap<String, AdditionLink>>labels: Option<Vec<Label>>scan_overview: Option<HashMap<String, NativeReportSummary>>

The scan overview attached in the metadata of tag

sbom_overview: Option<Box<SbomOverview>>accessories: Option<Vec<Accessory>>

Implementations