pub struct AuthproxySetting {
pub endpoint: Option<String>,
pub tokenreivew_endpoint: Option<String>,
pub skip_search: Option<bool>,
pub verify_cert: Option<bool>,
pub server_certificate: Option<String>,
}Fields
endpoint: Option<String>The fully qualified URI of login endpoint of authproxy, such as ‘https://192.168.1.2:8443/login’
tokenreivew_endpoint: Option<String>The fully qualified URI of token review endpoint of authproxy, such as ‘https://192.168.1.2:8443/tokenreview’
skip_search: Option<bool>The flag to determine whether Harbor can skip search the user/group when adding him as a member.
verify_cert: Option<bool>The flag to determine whether Harbor should verify the certificate when connecting to the auth proxy.
server_certificate: Option<String>The certificate to be pinned when connecting auth proxy.
Implementations
Sourceimpl AuthproxySetting
impl AuthproxySetting
pub fn new() -> AuthproxySetting