Configurations

Struct Configurations 

pub struct Configurations {
Show 55 fields pub auth_mode: Option<String>, pub primary_auth_mode: Option<Option<bool>>, pub ldap_base_dn: Option<String>, pub ldap_filter: Option<String>, pub ldap_group_base_dn: Option<String>, pub ldap_group_admin_dn: Option<String>, pub ldap_group_attribute_name: Option<String>, pub ldap_group_search_filter: Option<String>, pub ldap_group_search_scope: Option<i32>, pub ldap_group_attach_parallel: Option<bool>, pub ldap_scope: Option<i32>, pub ldap_search_dn: Option<String>, pub ldap_search_password: Option<String>, pub ldap_timeout: Option<i32>, pub ldap_uid: Option<String>, pub ldap_url: Option<String>, pub ldap_verify_cert: Option<bool>, pub ldap_group_membership_attribute: Option<String>, pub project_creation_restriction: Option<String>, pub read_only: Option<bool>, pub self_registration: Option<bool>, pub token_expiration: Option<i32>, pub uaa_client_id: Option<String>, pub uaa_client_secret: Option<String>, pub uaa_endpoint: Option<String>, pub uaa_verify_cert: Option<bool>, pub http_authproxy_endpoint: Option<String>, pub http_authproxy_tokenreview_endpoint: Option<String>, pub http_authproxy_admin_groups: Option<String>, pub http_authproxy_admin_usernames: Option<String>, pub http_authproxy_verify_cert: Option<bool>, pub http_authproxy_skip_search: Option<bool>, pub http_authproxy_server_certificate: Option<String>, pub oidc_name: Option<String>, pub oidc_endpoint: Option<String>, pub oidc_client_id: Option<String>, pub oidc_client_secret: Option<String>, pub oidc_groups_claim: Option<String>, pub oidc_admin_group: Option<String>, pub oidc_group_filter: Option<String>, pub oidc_scope: Option<String>, pub oidc_user_claim: Option<String>, pub oidc_verify_cert: Option<bool>, pub oidc_auto_onboard: Option<bool>, pub oidc_extra_redirect_parms: Option<String>, pub robot_token_duration: Option<i32>, pub robot_name_prefix: Option<String>, pub notification_enable: Option<bool>, pub quota_per_project_enable: Option<bool>, pub storage_per_project: Option<i32>, pub audit_log_forward_endpoint: Option<String>, pub skip_audit_log_database: Option<bool>, pub session_timeout: Option<i32>, pub scanner_skip_update_pulltime: Option<bool>, pub banner_message: Option<String>,
}

Fields

auth_mode: Option<String>

The auth mode of current system, such as "db_auth", "ldap_auth", "oidc_auth"

primary_auth_mode: Option<Option<bool>>

The flag to indicate whether the current auth mode should consider as a primary one.

ldap_base_dn: Option<String>

The Base DN for LDAP binding.

ldap_filter: Option<String>

The filter for LDAP search

ldap_group_base_dn: Option<String>

The base DN to search LDAP group.

ldap_group_admin_dn: Option<String>

Specify the ldap group which have the same privilege with Harbor admin

ldap_group_attribute_name: Option<String>

The attribute which is used as identity of the LDAP group, default is cn.’

ldap_group_search_filter: Option<String>

The filter to search the ldap group

ldap_group_search_scope: Option<i32>

The scope to search ldap group. ’‘0-LDAP_SCOPE_BASE, 1-LDAP_SCOPE_ONELEVEL, 2-LDAP_SCOPE_SUBTREE’’

ldap_group_attach_parallel: Option<bool>

Attach LDAP user group information in parallel, the parallel worker count is 5

ldap_scope: Option<i32>

The scope to search ldap users,‘0-LDAP_SCOPE_BASE, 1-LDAP_SCOPE_ONELEVEL, 2-LDAP_SCOPE_SUBTREE’

ldap_search_dn: Option<String>

The DN of the user to do the search.

ldap_search_password: Option<String>

The password of the ldap search dn

ldap_timeout: Option<i32>

Timeout in seconds for connection to LDAP server

ldap_uid: Option<String>

The attribute which is used as identity for the LDAP binding, such as "CN" or "SAMAccountname"

ldap_url: Option<String>

The URL of LDAP server

ldap_verify_cert: Option<bool>

Whether verify your OIDC server certificate, disable it if your OIDC server is hosted via self-hosted certificate.

ldap_group_membership_attribute: Option<String>

The user attribute to identify the group membership

project_creation_restriction: Option<String>

Indicate who can create projects, it could be ’‘adminonly’’ or ’‘everyone’’.

read_only: Option<bool>

The flag to indicate whether Harbor is in readonly mode.

self_registration: Option<bool>

Whether the Harbor instance supports self-registration. If it’’s set to false, admin need to add user to the instance.

token_expiration: Option<i32>

The expiration time of the token for internal Registry, in minutes.

uaa_client_id: Option<String>

The client id of UAA

uaa_client_secret: Option<String>

The client secret of the UAA

uaa_endpoint: Option<String>

The endpoint of the UAA

uaa_verify_cert: Option<bool>

Verify the certificate in UAA server

http_authproxy_endpoint: Option<String>

The endpoint of the HTTP auth

http_authproxy_tokenreview_endpoint: Option<String>

The token review endpoint

http_authproxy_admin_groups: Option<String>

The group which has the harbor admin privileges

http_authproxy_admin_usernames: Option<String>

The username which has the harbor admin privileges

http_authproxy_verify_cert: Option<bool>

Verify the HTTP auth provider’s certificate

http_authproxy_skip_search: Option<bool>

Search user before onboard

http_authproxy_server_certificate: Option<String>

The certificate of the HTTP auth provider

oidc_name: Option<String>

The OIDC provider name

oidc_endpoint: Option<String>

The endpoint of the OIDC provider

oidc_client_id: Option<String>

The client ID of the OIDC provider

oidc_client_secret: Option<String>

The OIDC provider secret

oidc_groups_claim: Option<String>

The attribute claims the group name

oidc_admin_group: Option<String>

The OIDC group which has the harbor admin privileges

oidc_group_filter: Option<String>

The OIDC group filter which filters out the group name doesn’t match the regular expression

oidc_scope: Option<String>

The scope of the OIDC provider

oidc_user_claim: Option<String>

The attribute claims the username

oidc_verify_cert: Option<bool>

Verify the OIDC provider’s certificate’

oidc_auto_onboard: Option<bool>

Auto onboard the OIDC user

oidc_extra_redirect_parms: Option<String>

Extra parameters to add when redirect request to OIDC provider

robot_token_duration: Option<i32>

The robot account token duration in days

robot_name_prefix: Option<String>

The rebot account name prefix

notification_enable: Option<bool>

Enable notification

quota_per_project_enable: Option<bool>

Enable quota per project

storage_per_project: Option<i32>

The storage quota per project

audit_log_forward_endpoint: Option<String>

The audit log forward endpoint

skip_audit_log_database: Option<bool>

Skip audit log database

session_timeout: Option<i32>

The session timeout for harbor, in minutes.

scanner_skip_update_pulltime: Option<bool>

Whether or not to skip update pull time for scanner

banner_message: Option<String>

The banner message for the UI.It is the stringified result of the banner message object

Implementations