GeneralInfo

Struct GeneralInfo 

pub struct GeneralInfo {
Show 15 fields pub banner_message: Option<Option<String>>, pub current_time: Option<Option<String>>, pub registry_url: Option<Option<String>>, pub external_url: Option<Option<String>>, pub auth_mode: Option<Option<String>>, pub primary_auth_mode: Option<Option<bool>>, pub project_creation_restriction: Option<Option<String>>, pub self_registration: Option<Option<bool>>, pub has_ca_root: Option<Option<bool>>, pub harbor_version: Option<Option<String>>, pub registry_storage_provider_name: Option<Option<String>>, pub read_only: Option<Option<bool>>, pub notification_enable: Option<Option<bool>>, pub authproxy_settings: Option<Box<AuthproxySetting>>, pub oidc_provider_name: Option<Option<String>>,
}

Fields

banner_message: Option<Option<String>>

The banner message for the UI. It is the stringified result of the banner message object.

current_time: Option<Option<String>>

The current time of the server.

registry_url: Option<Option<String>>

The url of registry against which the docker command should be issued.

external_url: Option<Option<String>>

The external URL of Harbor, with protocol.

auth_mode: Option<Option<String>>

The auth mode of current Harbor instance.

primary_auth_mode: Option<Option<bool>>

The flag to indicate whether the current auth mode should consider as a primary one.

project_creation_restriction: Option<Option<String>>

Indicate who can create projects, it could be ‘adminonly’ or ‘everyone’.

self_registration: Option<Option<bool>>

Indicate whether the Harbor instance enable user to register himself.

has_ca_root: Option<Option<bool>>

Indicate whether there is a ca root cert file ready for download in the file system.

harbor_version: Option<Option<String>>

The build version of Harbor.

registry_storage_provider_name: Option<Option<String>>

The storage provider’s name of Harbor registry

read_only: Option<Option<bool>>

The flag to indicate whether Harbor is in readonly mode.

notification_enable: Option<Option<bool>>

The flag to indicate whether notification mechanism is enabled on Harbor instance.

authproxy_settings: Option<Box<AuthproxySetting>>oidc_provider_name: Option<Option<String>>

The OIDC provider name, empty if current auth is not OIDC_auth or OIDC provider is not configured.

Implementations