pub struct NativeReportSummary {
pub report_id: Option<String>,
pub scan_status: Option<String>,
pub severity: Option<String>,
pub duration: Option<i64>,
pub summary: Option<Box<VulnerabilitySummary>>,
pub start_time: Option<String>,
pub end_time: Option<String>,
pub complete_percent: Option<i32>,
pub scanner: Option<Box<Scanner>>,
}Expand description
NativeReportSummary : The summary for the native report
Fields
report_id: Option<String>id of the native scan report
scan_status: Option<String>The status of the report generating process
severity: Option<String>The overall severity
duration: Option<i64>The seconds spent for generating the report
summary: Option<Box<VulnerabilitySummary>>start_time: Option<String>The start time of the scan process that generating report
end_time: Option<String>The end time of the scan process that generating report
complete_percent: Option<i32>The complete percent of the scanning which value is between 0 and 100
scanner: Option<Box<Scanner>>Implementations
Sourceimpl NativeReportSummary
impl NativeReportSummary
Sourcepub fn new() -> NativeReportSummary
pub fn new() -> NativeReportSummary
The summary for the native report