pub struct Project {Show 14 fields
pub project_id: Option<i32>,
pub owner_id: Option<i32>,
pub name: Option<String>,
pub registry_id: Option<i64>,
pub creation_time: Option<String>,
pub update_time: Option<String>,
pub deleted: Option<bool>,
pub owner_name: Option<String>,
pub togglable: Option<bool>,
pub current_user_role_id: Option<i32>,
pub current_user_role_ids: Option<Vec<i32>>,
pub repo_count: Option<i32>,
pub metadata: Option<Box<ProjectMetadata>>,
pub cve_allowlist: Option<Box<CveAllowlist>>,
}Fields
project_id: Option<i32>Project ID
owner_id: Option<i32>The owner ID of the project always means the creator of the project.
name: Option<String>The name of the project.
registry_id: Option<i64>The ID of referenced registry when the project is a proxy cache project.
creation_time: Option<String>The creation time of the project.
update_time: Option<String>The update time of the project.
deleted: Option<bool>A deletion mark of the project.
owner_name: Option<String>The owner name of the project.
togglable: Option<bool>Correspond to the UI about whether the project’s publicity is updatable (for UI)
current_user_role_id: Option<i32>The role ID with highest permission of the current user who triggered the API (for UI). This attribute is deprecated and will be removed in future versions.
current_user_role_ids: Option<Vec<i32>>The list of role ID of the current user who triggered the API (for UI)
repo_count: Option<i32>The number of the repositories under this project.
metadata: Option<Box<ProjectMetadata>>cve_allowlist: Option<Box<CveAllowlist>>Implementations