pub struct ProjectMemberEntity {
pub id: Option<i32>,
pub project_id: Option<i32>,
pub entity_name: Option<String>,
pub role_name: Option<String>,
pub role_id: Option<i32>,
pub entity_id: Option<i32>,
pub entity_type: Option<String>,
}Fields
id: Option<i32>the project member id
project_id: Option<i32>the project id
entity_name: Option<String>the name of the group member.
role_name: Option<String>the name of the role
role_id: Option<i32>the role id
entity_id: Option<i32>the id of entity, if the member is a user, it is user_id in user table. if the member is a user group, it is the user group’s ID in user_group table.
entity_type: Option<String>the entity’s type, u for user entity, g for group entity.
Implementations
Sourceimpl ProjectMemberEntity
impl ProjectMemberEntity
pub fn new() -> ProjectMemberEntity