pub struct ReplicationTask {
pub id: Option<i32>,
pub execution_id: Option<i32>,
pub status: Option<String>,
pub job_id: Option<String>,
pub operation: Option<String>,
pub resource_type: Option<String>,
pub src_resource: Option<String>,
pub dst_resource: Option<String>,
pub start_time: Option<String>,
pub end_time: Option<String>,
}Expand description
ReplicationTask : The replication task
Fields
id: Option<i32>The ID of the task
execution_id: Option<i32>The ID of the execution that the task belongs to
status: Option<String>The status of the task
job_id: Option<String>The ID of the underlying job that the task related to
operation: Option<String>The operation of the task
resource_type: Option<String>The type of the resource that the task operates
src_resource: Option<String>The source resource that the task operates
dst_resource: Option<String>The destination resource that the task operates
start_time: Option<String>The start time of the task
end_time: Option<String>The end time of the task
Implementations
Sourceimpl ReplicationTask
impl ReplicationTask
Sourcepub fn new() -> ReplicationTask
pub fn new() -> ReplicationTask
The replication task