pub struct Repository {
pub id: Option<i64>,
pub project_id: Option<i64>,
pub name: Option<String>,
pub description: Option<String>,
pub artifact_count: Option<i64>,
pub pull_count: Option<i64>,
pub creation_time: Option<Option<String>>,
pub update_time: Option<String>,
}Fields
id: Option<i64>The ID of the repository
project_id: Option<i64>The ID of the project that the repository belongs to
name: Option<String>The name of the repository
description: Option<String>The description of the repository
artifact_count: Option<i64>The count of the artifacts inside the repository
pull_count: Option<i64>The count that the artifact inside the repository pulled
creation_time: Option<Option<String>>The creation time of the repository
update_time: Option<String>The update time of the repository
Implementations
Sourceimpl Repository
impl Repository
pub fn new() -> Repository