pub struct Robot {Show 14 fields
pub id: Option<i64>,
pub name: Option<String>,
pub description: Option<String>,
pub secret: Option<String>,
pub level: Option<String>,
pub duration: Option<Option<i64>>,
pub editable: Option<bool>,
pub disable: Option<bool>,
pub expires_at: Option<i64>,
pub permissions: Option<Vec<RobotPermission>>,
pub creator_type: Option<String>,
pub creator_ref: Option<i32>,
pub creation_time: Option<String>,
pub update_time: Option<String>,
}Fields
id: Option<i64>The ID of the robot
name: Option<String>The name of the robot
description: Option<String>The description of the robot
secret: Option<String>The secret of the robot
level: Option<String>The level of the robot, project or system
duration: Option<Option<i64>>The duration of the robot in days, duration must be either -1(Never) or a positive integer
editable: Option<bool>The editable status of the robot
disable: Option<bool>The disable status of the robot
expires_at: Option<i64>The expiration date of the robot
permissions: Option<Vec<RobotPermission>>creator_type: Option<String>The type of the robot creator, like local(harbor_user) or robot.
creator_ref: Option<i32>The reference of the robot creator, like the id of harbor user.
creation_time: Option<String>The creation time of the robot.
update_time: Option<String>The update time of the robot.
Implementations