pub struct SbomOverview {
pub start_time: Option<String>,
pub end_time: Option<String>,
pub scan_status: Option<String>,
pub sbom_digest: Option<String>,
pub report_id: Option<String>,
pub duration: Option<i64>,
pub scanner: Option<Box<Scanner>>,
}Expand description
SbomOverview : The generate SBOM overview information
Fields
start_time: Option<String>The start time of the generating sbom report task
end_time: Option<String>The end time of the generating sbom report task
scan_status: Option<String>The status of the generating SBOM task
sbom_digest: Option<String>The digest of the generated SBOM accessory
report_id: Option<String>id of the native scan report
duration: Option<i64>Time in seconds required to create the report
scanner: Option<Box<Scanner>>Implementations
Sourceimpl SbomOverview
impl SbomOverview
Sourcepub fn new() -> SbomOverview
pub fn new() -> SbomOverview
The generate SBOM overview information