pub struct ScanDataExportJob {
pub id: Option<i64>,
}Expand description
ScanDataExportJob : The metadata associated with the scan data export job
Fields
id: Option<i64>The id of the scan data export job
Implementations
Sourceimpl ScanDataExportJob
impl ScanDataExportJob
Sourcepub fn new() -> ScanDataExportJob
pub fn new() -> ScanDataExportJob
The metadata associated with the scan data export job