pub struct ScanDataExportRequest {
pub job_name: Option<String>,
pub projects: Option<Vec<i64>>,
pub labels: Option<Vec<i64>>,
pub repositories: Option<String>,
pub cve_ids: Option<String>,
pub tags: Option<String>,
}Expand description
ScanDataExportRequest : The criteria to select the scan data to export.
Fields
job_name: Option<String>Name of the scan data export job
projects: Option<Vec<i64>>A list of one or more projects for which to export the scan data, currently only one project is supported due to performance concerns, but define as array for extension in the future.
labels: Option<Vec<i64>>A list of one or more labels for which to export the scan data, defaults to all if empty
repositories: Option<String>A list of repositories for which to export the scan data, defaults to all if empty
cve_ids: Option<String>CVE-IDs for which to export data. Multiple CVE-IDs can be specified by separating using ‘,’ and enclosed between ‘{}’. Defaults to all if empty
A list of tags enclosed within ‘{}’. Defaults to all if empty
Implementations
Sourceimpl ScanDataExportRequest
impl ScanDataExportRequest
Sourcepub fn new() -> ScanDataExportRequest
pub fn new() -> ScanDataExportRequest
The criteria to select the scan data to export.