ScannerRegistration

Struct ScannerRegistration 

pub struct ScannerRegistration {
Show 17 fields pub uuid: Option<String>, pub name: Option<String>, pub description: Option<String>, pub url: Option<String>, pub disabled: Option<bool>, pub is_default: Option<bool>, pub auth: Option<String>, pub access_credential: Option<String>, pub skip_cert_verify: Option<bool>, pub use_internal_addr: Option<bool>, pub create_time: Option<String>, pub update_time: Option<String>, pub adapter: Option<String>, pub vendor: Option<String>, pub version: Option<String>, pub health: Option<String>, pub capabilities: Option<HashMap<String, Value>>,
}
ScannerRegistration : Registration represents a named configuration for invoking a scanner via its adapter.

Fields

uuid: Option<String>

The unique identifier of this registration.

name: Option<String>

The name of this registration.

description: Option<String>

An optional description of this registration.

url: Option<String>

A base URL of the scanner adapter

disabled: Option<bool>

Indicate whether the registration is enabled or not

is_default: Option<bool>

Indicate if the registration is set as the system default one

auth: Option<String>

Specify what authentication approach is adopted for the HTTP communications. Supported types Basic", "Bearer" and api key header "X-ScannerAdapter-API-Key"

access_credential: Option<String>

An optional value of the HTTP Authorization header sent with each request to the Scanner Adapter API.

skip_cert_verify: Option<bool>

Indicate if skip the certificate verification when sending HTTP requests

use_internal_addr: Option<bool>

Indicate whether use internal registry addr for the scanner to pull content or not

create_time: Option<String>

The creation time of this registration

update_time: Option<String>

The update time of this registration

adapter: Option<String>

Optional property to describe the name of the scanner registration

vendor: Option<String>

Optional property to describe the vendor of the scanner registration

version: Option<String>

Optional property to describe the version of the scanner registration

health: Option<String>

Indicate the healthy of the registration

capabilities: Option<HashMap<String, Value>>

Indicates the capabilities of the scanner, e.g. support_vulnerability or support_sbom.

Implementations

Source

impl ScannerRegistration

pub fn new() -> ScannerRegistration

Registration represents a named configuration for invoking a scanner via its adapter.