pub struct ScannerRegistrationReq {
pub name: String,
pub description: Option<String>,
pub url: String,
pub auth: Option<String>,
pub access_credential: Option<String>,
pub skip_cert_verify: Option<bool>,
pub use_internal_addr: Option<bool>,
pub disabled: Option<bool>,
}Fields
name: StringThe name of this registration
description: Option<String>An optional description of this registration.
url: StringA base URL of the scanner adapter.
auth: Option<String>Specify what authentication approach is adopted for the HTTP communications. Supported types Basic", "Bearer" and api key header "X-ScannerAdapter-API-Key"
access_credential: Option<String>An optional value of the HTTP Authorization header sent with each request to the Scanner Adapter API.
skip_cert_verify: Option<bool>Indicate if skip the certificate verification when sending HTTP requests
use_internal_addr: Option<bool>Indicate whether use internal registry addr for the scanner to pull content or not
disabled: Option<bool>Indicate whether the registration is enabled or not
Implementations
Sourceimpl ScannerRegistrationReq
impl ScannerRegistrationReq
pub fn new(name: String, url: String) -> ScannerRegistrationReq