pub struct Search {
pub project: Option<Vec<Project>>,
pub repository: Option<Vec<SearchRepository>>,
}Fields
project: Option<Vec<Project>>Search results of the projects that matched the filter keywords.
repository: Option<Vec<SearchRepository>>Search results of the repositories that matched the filter keywords.
Implementations