pub struct SearchRepository {
pub project_id: Option<i32>,
pub project_name: Option<String>,
pub project_public: Option<bool>,
pub repository_name: Option<String>,
pub pull_count: Option<i32>,
pub artifact_count: Option<i32>,
}Fields
project_id: Option<i32>The ID of the project that the repository belongs to
project_name: Option<String>The name of the project that the repository belongs to
project_public: Option<bool>The flag to indicate the publicity of the project that the repository belongs to (1 is public, 0 is not)
repository_name: Option<String>The name of the repository
pull_count: Option<i32>The count how many times the repository is pulled
artifact_count: Option<i32>The count of artifacts in the repository
Implementations
Sourceimpl SearchRepository
impl SearchRepository
pub fn new() -> SearchRepository