pub struct Statistic {
pub private_project_count: Option<i64>,
pub private_repo_count: Option<i64>,
pub public_project_count: Option<i64>,
pub public_repo_count: Option<i64>,
pub total_project_count: Option<i64>,
pub total_repo_count: Option<i64>,
pub total_storage_consumption: Option<i64>,
}Fields
private_project_count: Option<i64>The count of the private projects
private_repo_count: Option<i64>The count of the private repositories
public_project_count: Option<i64>The count of the public projects
public_repo_count: Option<i64>The count of the public repositories
total_project_count: Option<i64>The count of the total projects, only be seen by the system admin
total_repo_count: Option<i64>The count of the total repositories, only be seen by the system admin
total_storage_consumption: Option<i64>The total storage consumption of blobs, only be seen by the system admin
Implementations