pub struct Stats {
pub total: Option<i32>,
pub completed: Option<i32>,
pub metrics: Option<HashMap<String, i32>>,
pub ongoing: Option<bool>,
pub trigger: Option<Trigger>,
}Expand description
Stats : Stats provides the overall progress of the scan all process.
Fields
total: Option<i32>The total number of scan processes triggered by the scan all action
completed: Option<i32>The number of the finished scan processes triggered by the scan all action
metrics: Option<HashMap<String, i32>>The metrics data for the each status
ongoing: Option<bool>A flag indicating job status of scan all.
trigger: Option<Trigger>The trigger of the scan all job.
Implementations