pub struct UserResp {
pub email: Option<String>,
pub realname: Option<String>,
pub comment: Option<String>,
pub user_id: Option<i32>,
pub username: Option<String>,
pub sysadmin_flag: Option<bool>,
pub admin_role_in_auth: Option<bool>,
pub oidc_user_meta: Option<Box<OidcUserInfo>>,
pub creation_time: Option<String>,
pub update_time: Option<String>,
}Fields
email: Option<String>realname: Option<String>comment: Option<String>user_id: Option<i32>username: Option<String>sysadmin_flag: Option<bool>admin_role_in_auth: Option<bool>indicate the admin privilege is grant by authenticator (LDAP), is always false unless it is the current login user
oidc_user_meta: Option<Box<OidcUserInfo>>creation_time: Option<String>The creation time of the user.
update_time: Option<String>The update time of the user.
Implementations