pub struct Worker {
pub id: Option<String>,
pub pool_id: Option<String>,
pub job_name: Option<String>,
pub job_id: Option<String>,
pub start_at: Option<Option<String>>,
pub check_in: Option<String>,
pub checkin_at: Option<Option<String>>,
}Expand description
Worker : worker in the pool
Fields
id: Option<String>the id of the worker
pool_id: Option<String>the id of the worker pool
job_name: Option<String>the name of the running job in the worker
job_id: Option<String>the id of the running job in the worker
start_at: Option<Option<String>>The start time of the worker
check_in: Option<String>the checkin of the running job in the worker
checkin_at: Option<Option<String>>The checkin time of the worker
Implementations