pub struct GetVulnerabilitiesAdditionParams {
pub project_name: String,
pub repository_name: String,
pub reference: String,
pub x_request_id: Option<String>,
pub x_accept_vulnerabilities: Option<String>,
}Expand description
struct for passing parameters to the method get_vulnerabilities_addition
Fields
project_name: StringThe name of the project
repository_name: StringThe name of the repository. If it contains slash, encode it twice over with URL encoding. e.g. a/b -> a%2Fb -> a%252Fb
reference: StringThe reference of the artifact, can be digest or tag
x_request_id: Option<String>An unique ID for the request
x_accept_vulnerabilities: Option<String>A comma-separated lists of MIME types for the scan report or scan summary. The first mime type will be used when the report found for it. Currently the mime type supports ‘application/vnd.scanner.adapter.vuln.report.harbor+json; version=1.0’ and ‘application/vnd.security.vulnerability.report; version=1.1’