Structs
- Create
Immu Rule Params - struct for passing parameters to the method
create_immu_rule - Delete
Immu Rule Params - struct for passing parameters to the method
delete_immu_rule - List
Immu Rules Params - struct for passing parameters to the method
list_immu_rules - Update
Immu Rule Params - struct for passing parameters to the method
update_immu_rule
Enums
- Create
Immu Rule Error - struct for typed errors of method
create_immu_rule - Delete
Immu Rule Error - struct for typed errors of method
delete_immu_rule - List
Immu Rules Error - struct for typed errors of method
list_immu_rules - Update
Immu Rule Error - struct for typed errors of method
update_immu_rule
Functions
- create_
immu_ rule - This endpoint add an immutable tag rule to the project
- delete_
immu_ rule - list_
immu_ rules - This endpoint returns the immutable tag rules of a project
- update_
immu_ rule