Module label_api

Module label_api 

Structs

CreateLabelParams
struct for passing parameters to the method create_label
DeleteLabelParams
struct for passing parameters to the method delete_label
GetLabelByIdParams
struct for passing parameters to the method get_label_by_id
ListLabelsParams
struct for passing parameters to the method list_labels
UpdateLabelParams
struct for passing parameters to the method update_label

Enums

CreateLabelError
struct for typed errors of method create_label
DeleteLabelError
struct for typed errors of method delete_label
GetLabelByIdError
struct for typed errors of method get_label_by_id
ListLabelsError
struct for typed errors of method list_labels
UpdateLabelError
struct for typed errors of method update_label

Functions

create_label
This endpoint let user creates a label.
delete_label
Delete the label specified by ID.
get_label_by_id
This endpoint let user get the label by specific ID.
list_labels
This endpoint let user list labels by name, scope and project_id
update_label
This endpoint let user update label properties.