Structs
- GetPing
Params - struct for passing parameters to the method
get_ping
Enums
- GetPing
Error - struct for typed errors of method
get_ping
Functions
- get_
ping - This API simply replies a pong to indicate the process to handle API is up, disregarding the health status of dependent components. This path does not require any authentication.