Structs
- Create
Project Params - struct for passing parameters to the method
create_project - Delete
Project Params - struct for passing parameters to the method
delete_project - GetLogs
Params - struct for passing parameters to the method
get_logs - GetProject
Deletable Params - struct for passing parameters to the method
get_project_deletable - GetProject
Params - struct for passing parameters to the method
get_project - GetProject
Summary Params - struct for passing parameters to the method
get_project_summary - GetScanner
OfProject Params - struct for passing parameters to the method
get_scanner_of_project - Head
Project Params - struct for passing parameters to the method
head_project - List
Artifacts OfProject Params - struct for passing parameters to the method
list_artifacts_of_project - List
Projects Params - struct for passing parameters to the method
list_projects - List
Scanner Candidates OfProject Params - struct for passing parameters to the method
list_scanner_candidates_of_project - SetScanner
OfProject Params - struct for passing parameters to the method
set_scanner_of_project - Update
Project Params - struct for passing parameters to the method
update_project
Enums
- Create
Project Error - struct for typed errors of method
create_project - Delete
Project Error - struct for typed errors of method
delete_project - GetLogs
Error - struct for typed errors of method
get_logs - GetProject
Deletable Error - struct for typed errors of method
get_project_deletable - GetProject
Error - struct for typed errors of method
get_project - GetProject
Summary Error - struct for typed errors of method
get_project_summary - GetScanner
OfProject Error - struct for typed errors of method
get_scanner_of_project - Head
Project Error - struct for typed errors of method
head_project - List
Artifacts OfProject Error - struct for typed errors of method
list_artifacts_of_project - List
Projects Error - struct for typed errors of method
list_projects - List
Scanner Candidates OfProject Error - struct for typed errors of method
list_scanner_candidates_of_project - SetScanner
OfProject Error - struct for typed errors of method
set_scanner_of_project - Update
Project Error - struct for typed errors of method
update_project
Functions
- create_
project - This endpoint is for user to create a new project.
- delete_
project - This endpoint is aimed to delete project by project ID.
- get_
logs - Get recent logs of the projects
- get_
project - This endpoint returns specific project information by project ID.
- get_
project_ deletable - Get the deletable status of the project
- get_
project_ summary - Get summary of the project.
- get_
scanner_ of_ project - Get the scanner registration of the specified project. If no scanner registration is configured for the specified project, the system default scanner registration will be returned.
- head_
project - This endpoint is used to check if the project name provided already exist.
- list_
artifacts_ of_ project - List artifacts of the specified project
- list_
projects - This endpoint returns projects created by Harbor.
- list_
scanner_ candidates_ of_ project - Retrieve the system configured scanner registrations as candidates of setting project level scanner.
- set_
scanner_ of_ project - Set one of the system configured scanner registration as the indepndent scanner of the specified project.
- update_
project - This endpoint is aimed to update the properties of a project.