Structs
- Create
Robot Params - struct for passing parameters to the method
create_robot - Delete
Robot Params - struct for passing parameters to the method
delete_robot - GetRobot
ById Params - struct for passing parameters to the method
get_robot_by_id - List
Robot Params - struct for passing parameters to the method
list_robot - Refresh
SecParams - struct for passing parameters to the method
refresh_sec - Update
Robot Params - struct for passing parameters to the method
update_robot
Enums
- Create
Robot Error - struct for typed errors of method
create_robot - Delete
Robot Error - struct for typed errors of method
delete_robot - GetRobot
ById Error - struct for typed errors of method
get_robot_by_id - List
Robot Error - struct for typed errors of method
list_robot - Refresh
SecError - struct for typed errors of method
refresh_sec - Update
Robot Error - struct for typed errors of method
update_robot
Functions
- create_
robot - Create a robot account
- delete_
robot - This endpoint deletes specific robot account information by robot ID.
- get_
robot_ by_ id - This endpoint returns specific robot account information by robot ID.
- list_
robot - List the robot accounts with the specified level and project.
- refresh_
sec - Refresh the robot secret
- update_
robot - This endpoint updates specific robot account information by robot ID.