Structs
- Download
Scan Data Params - struct for passing parameters to the method
download_scan_data - Export
Scan Data Params - struct for passing parameters to the method
export_scan_data - GetScan
Data Export Execution List Params - struct for passing parameters to the method
get_scan_data_export_execution_list - GetScan
Data Export Execution Params - struct for passing parameters to the method
get_scan_data_export_execution
Enums
- Download
Scan Data Error - struct for typed errors of method
download_scan_data - Export
Scan Data Error - struct for typed errors of method
export_scan_data - GetScan
Data Export Execution Error - struct for typed errors of method
get_scan_data_export_execution - GetScan
Data Export Execution List Error - struct for typed errors of method
get_scan_data_export_execution_list
Functions
- download_
scan_ data - Download the scan data report. Default format is CSV
- export_
scan_ data - Export scan data for selected projects
- get_
scan_ data_ export_ execution - Get the scan data export execution specified by ID
- get_
scan_ data_ export_ execution_ list - Get a list of specific scan data export execution jobs for a specified user