Structs
- Create
Scanner Params - struct for passing parameters to the method
create_scanner - Delete
Scanner Params - struct for passing parameters to the method
delete_scanner - GetScanner
Metadata Params - struct for passing parameters to the method
get_scanner_metadata - GetScanner
Params - struct for passing parameters to the method
get_scanner - List
Scanners Params - struct for passing parameters to the method
list_scanners - Ping
Scanner Params - struct for passing parameters to the method
ping_scanner - SetScanner
AsDefault Params - struct for passing parameters to the method
set_scanner_as_default - Update
Scanner Params - struct for passing parameters to the method
update_scanner
Enums
- Create
Scanner Error - struct for typed errors of method
create_scanner - Delete
Scanner Error - struct for typed errors of method
delete_scanner - GetScanner
Error - struct for typed errors of method
get_scanner - GetScanner
Metadata Error - struct for typed errors of method
get_scanner_metadata - List
Scanners Error - struct for typed errors of method
list_scanners - Ping
Scanner Error - struct for typed errors of method
ping_scanner - SetScanner
AsDefault Error - struct for typed errors of method
set_scanner_as_default - Update
Scanner Error - struct for typed errors of method
update_scanner
Functions
- create_
scanner - Creats a new scanner registration with the given data.
- delete_
scanner - Deletes the specified scanner registration.
- get_
scanner - Retruns the details of the specified scanner registration.
- get_
scanner_ metadata - Get the metadata of the specified scanner registration, including the capabilities and customized properties.
- list_
scanners - Returns a list of currently configured scanner registrations.
- ping_
scanner - Pings scanner adapter to test endpoint URL and authorization settings.
- set_
scanner_ as_ default - Set the specified scanner registration as the system default one.
- update_
scanner - Updates the specified scanner registration.