Structs
- Search
Params - struct for passing parameters to the method
search
Enums
- Search
Error - struct for typed errors of method
search
Functions
- search
- The Search endpoint returns information about the projects and repositories offered at public status or related to the current logged in user. The response includes the project and repository list in a proper display order.