Structs
- GetCert
Params - struct for passing parameters to the method
get_cert - GetSystem
Info Params - struct for passing parameters to the method
get_system_info - GetVolumes
Params - struct for passing parameters to the method
get_volumes
Enums
- GetCert
Error - struct for typed errors of method
get_cert - GetSystem
Info Error - struct for typed errors of method
get_system_info - GetVolumes
Error - struct for typed errors of method
get_volumes
Functions
- get_
cert - This endpoint is for downloading a default root certificate.
- get_
system_ info - This API is for retrieving general system info, this can be called by anonymous request. Some attributes will be omitted in the response when this API is called by anonymous request.
- get_
volumes - This endpoint is for retrieving system volume info that only provides for admin user. Note that the response only reflects the storage status of local disk.