Structs
- Create
User Params - struct for passing parameters to the method
create_user - Delete
User Params - struct for passing parameters to the method
delete_user - GetCurrent
User Info Params - struct for passing parameters to the method
get_current_user_info - GetCurrent
User Permissions Params - struct for passing parameters to the method
get_current_user_permissions - GetUser
Params - struct for passing parameters to the method
get_user - List
Users Params - struct for passing parameters to the method
list_users - Search
Users Params - struct for passing parameters to the method
search_users - SetCli
Secret Params - struct for passing parameters to the method
set_cli_secret - SetUser
SysAdmin Params - struct for passing parameters to the method
set_user_sys_admin - Update
User Password Params - struct for passing parameters to the method
update_user_password - Update
User Profile Params - struct for passing parameters to the method
update_user_profile
Enums
- Create
User Error - struct for typed errors of method
create_user - Delete
User Error - struct for typed errors of method
delete_user - GetCurrent
User Info Error - struct for typed errors of method
get_current_user_info - GetCurrent
User Permissions Error - struct for typed errors of method
get_current_user_permissions - GetUser
Error - struct for typed errors of method
get_user - List
Users Error - struct for typed errors of method
list_users - Search
Users Error - struct for typed errors of method
search_users - SetCli
Secret Error - struct for typed errors of method
set_cli_secret - SetUser
SysAdmin Error - struct for typed errors of method
set_user_sys_admin - Update
User Password Error - struct for typed errors of method
update_user_password - Update
User Profile Error - struct for typed errors of method
update_user_profile
Functions
- create_
user - This API can be used only when the authentication mode is for local DB. When self registration is disabled.
- delete_
user - This endpoint let administrator of Harbor mark a registered user as removed.It actually won’t be deleted from DB.
- get_
current_ user_ info - get_
current_ user_ permissions - get_
user - list_
users - search_
users - This endpoint is to search the users by username. It’s open for all authenticated requests.
- set_
cli_ secret - This endpoint let user generate a new CLI secret for himself. This API only works when auth mode is set to ‘OIDC’. Once this API returns with successful status, the old secret will be invalid, as there will be only one CLI secret for a user.
- set_
user_ sys_ admin - update_
user_ password - This endpoint is for user to update password. Users with the admin role can change any user’s password. Regular users can change only their own password.
- update_
user_ profile