Structs
- Create
Webhook Policy OfProject Params - struct for passing parameters to the method
create_webhook_policy_of_project - Delete
Webhook Policy OfProject Params - struct for passing parameters to the method
delete_webhook_policy_of_project - GetLogs
OfWebhook Task Params - struct for passing parameters to the method
get_logs_of_webhook_task - GetSupported
Event Types Params - struct for passing parameters to the method
get_supported_event_types - GetWebhook
Policy OfProject Params - struct for passing parameters to the method
get_webhook_policy_of_project - Last
Trigger Params - struct for passing parameters to the method
last_trigger - List
Executions OfWebhook Policy Params - struct for passing parameters to the method
list_executions_of_webhook_policy - List
Tasks OfWebhook Execution Params - struct for passing parameters to the method
list_tasks_of_webhook_execution - List
Webhook Policies OfProject Params - struct for passing parameters to the method
list_webhook_policies_of_project - Update
Webhook Policy OfProject Params - struct for passing parameters to the method
update_webhook_policy_of_project
Enums
- Create
Webhook Policy OfProject Error - struct for typed errors of method
create_webhook_policy_of_project - Delete
Webhook Policy OfProject Error - struct for typed errors of method
delete_webhook_policy_of_project - GetLogs
OfWebhook Task Error - struct for typed errors of method
get_logs_of_webhook_task - GetSupported
Event Types Error - struct for typed errors of method
get_supported_event_types - GetWebhook
Policy OfProject Error - struct for typed errors of method
get_webhook_policy_of_project - Last
Trigger Error - struct for typed errors of method
last_trigger - List
Executions OfWebhook Policy Error - struct for typed errors of method
list_executions_of_webhook_policy - List
Tasks OfWebhook Execution Error - struct for typed errors of method
list_tasks_of_webhook_execution - List
Webhook Policies OfProject Error - struct for typed errors of method
list_webhook_policies_of_project - Update
Webhook Policy OfProject Error - struct for typed errors of method
update_webhook_policy_of_project
Functions
- create_
webhook_ policy_ of_ project - This endpoint create a webhook policy if the project does not have one.
- delete_
webhook_ policy_ of_ project - This endpoint is aimed to delete webhookpolicy of a project.
- get_
logs_ of_ webhook_ task - This endpoint returns the logs of a specific webhook task.
- get_
supported_ event_ types - Get supported event types and notify types.
- get_
webhook_ policy_ of_ project - This endpoint returns specified webhook policy of a project.
- last_
trigger Deprecated - This endpoint returns last trigger information of project webhook policy.
- list_
executions_ of_ webhook_ policy - This endpoint returns the executions of a specific webhook policy.
- list_
tasks_ of_ webhook_ execution - This endpoint returns the tasks of a specific webhook execution.
- list_
webhook_ policies_ of_ project - This endpoint returns webhook policies of a project.
- update_
webhook_ policy_ of_ project - This endpoint is aimed to update the webhook policy of a project.