pub struct ProjectMetadata {
pub public: Option<String>,
pub enable_content_trust: Option<Option<String>>,
pub enable_content_trust_cosign: Option<Option<String>>,
pub prevent_vul: Option<Option<String>>,
pub severity: Option<Option<String>>,
pub auto_scan: Option<Option<String>>,
pub auto_sbom_generation: Option<Option<String>>,
pub reuse_sys_cve_allowlist: Option<Option<String>>,
pub retention_id: Option<Option<String>>,
pub proxy_speed_kb: Option<Option<String>>,
}Fields
public: Option<String>The public status of the project. The valid values are "true", "false".
enable_content_trust: Option<Option<String>>Whether content trust is enabled or not. If it is enabled, user can’t pull unsigned images from this project. The valid values are "true", "false".
enable_content_trust_cosign: Option<Option<String>>Whether cosign content trust is enabled or not. If it is enabled, user can’t pull images without cosign signature from this project. The valid values are "true", "false".
prevent_vul: Option<Option<String>>Whether prevent the vulnerable images from running. The valid values are "true", "false".
severity: Option<Option<String>>If the vulnerability is high than severity defined here, the images can’t be pulled. The valid values are "none", "low", "medium", "high", "critical".
auto_scan: Option<Option<String>>Whether scan images automatically when pushing. The valid values are "true", "false".
auto_sbom_generation: Option<Option<String>>Whether generating SBOM automatically when pushing a subject artifact. The valid values are "true", "false".
reuse_sys_cve_allowlist: Option<Option<String>>Whether this project reuse the system level CVE allowlist as the allowlist of its own. The valid values are "true", "false". If it is set to "true" the actual allowlist associate with this project, if any, will be ignored.
retention_id: Option<Option<String>>The ID of the tag retention policy for the project
proxy_speed_kb: Option<Option<String>>The bandwidth limit of proxy cache, in Kbps (kilobits per second). It limits the communication between Harbor and the upstream registry, not the client and the Harbor.
Implementations
Sourceimpl ProjectMetadata
impl ProjectMetadata
pub fn new() -> ProjectMetadata